==> flutter_conscent_plugin-0.3.0.tar.gz: lib/webview.dart <==
// import 'package:flutter/material.dart';
// import 'package:webview_flutter/webview_flutter.dart';

// void main() => runApp(MyAppgg());

// class MyAppgg extends StatelessWidget {

// const MyAppgg({super.key});

//   @override
//   Widget build(BuildContext context) {
//     return MaterialApp(home: Scaffold(body: WebViewLoad()));
//   }
// }

// class WebViewLoad extends StatefulWidget {
//   WebViewLoadUI createState() => WebViewLoadUI();
// }

// class WebViewLoadUI extends State<WebViewLoad> {


import 'package:flutter/material.dart';
import 'package:http/http.dart' as http;
import 'package:shared_preferences/shared_preferences.dart';
import 'package:webview_flutter/webview_flutter.dart';

import 'ConscentInitializer.dart';
import 'ConscentMethods.dart';
import 'Model/APIMode.dart';
import 'Model/loginChallengeget.dart';
//import 'package:flutter_new/defaultSubscribtion.dart';

void main() {
  runApp(
    const MaterialApp(
      home: WebViewApp(),
    ),
  );
}

class WebViewApp extends StatefulWidget {
  const WebViewApp({super.key});

  @override
  State<WebViewApp> createState() => _WebViewAppState();
}

class _WebViewAppState extends State<WebViewApp> {
  String? loginId;
  // String? sessionId;

  bool showContent = false;
  bool isLoaded = false;
  final clientId = TextEditingController();
  final clientContentId = TextEditingController();
  // final sessionId = TextEditingController();

  @override
  void initState() {
    if (mounted) {
      getLoginChallengeId();
    }
    super.initState();
  }

  getLoginChallengeId() async {
    final prefs = await SharedPreferences.getInstance();
    loginId = prefs.getString('loginID');
    print(loginId.toString());
    getSessionID(loginId.toString());
    setState(() {});
  }

  Future<String> getSessionID(String loginId) async {
    print('getSessionId------');
    var uri = Uri.parse('${APIMode.BASE_URL}api/v1/login-challenge/$loginId');
    print(uri);
    var response = await http.get(uri);
    if (response.statusCode == 200) {
      LoginChallengeget loginChallengeget =
          loginChallengegetFromJson(response.body);
      final prefs = await SharedPreferences.getInstance();
      print('WebViewApp sessionId ${prefs.getString('sessionId')}');
      String sessionId = loginChallengeget.toString();
      prefs.setString('sessionId', sessionId);
      print(loginChallengeget.toJson());
      CircularProgressIndicator();
      return sessionId;
    } else {
      ConscentMethods().onPluginError(response.body);
    }
    return '';
  }

  Future<void> submitDatas(
      String clientId, String clientContentId, String sessionId) async {
    print('sessionId xyz= $sessionId');
    var response = await http
        .post(Uri.parse('${APIMode.BASE_URL}api/v1/content/access'), body: {
      "clientId": '${ConscentInitializer.mClientId}',
      "clientContentId": '${ConscentInitializer.mContentId}',
      "sessionId": sessionId,
    });
    print('-------------------------------------------------------');
    print('${response.body}---- status---${response.statusCode}');

    if (response.statusCode == 201) {
      var responseString = response.body;

      Navigator.pop(context, {"response": responseString});
    } else {
      ConscentMethods().onPluginError(response.body);
    }
  }

  JavascriptChannel _javascriptChannel() {
    print('javascript');
    return JavascriptChannel(
        name: 'LOGINCHALLENGE',
        onMessageReceived: (JavascriptMessage message) async {
          print(message.message);
          if (message.message == 'loginSuccess') {
            CircularProgressIndicator();
            print('javascript----------');
            String sessionId = await getSessionID(loginId!);
            submitDatas('${ConscentInitializer.mClientId}',
                '${ConscentInitializer.mContentId}', sessionId);
          }
        });
  }

  // Home

  Widget homeBody() {
    return !isLoaded
        ? const CircularProgressIndicator()
        : Padding(
            padding: const EdgeInsets.all(8.0),
          );
  }

  //home

  // ... to here.

  @override
  Widget build(BuildContext context) {
    javascriptChannels:
    <JavascriptChannel>{_javascriptChannel()};
    // getLoginChallengeId();
    var flutterWebViewPlugin;
    print(loginId);
    print('kunallllllll');

    return Scaffold(
      appBar: AppBar(
        title: const Text('Conscent'),
      ),
      body: loginId != null
          ? WebView(
              initialUrl:
                  '${APIMode.SERVICE_BASE_URL}/overlay?clientId=${ConscentInitializer.mClientId}&clientContentId=${ConscentInitializer.mContentId}&loginChallenge=$loginId',
              javascriptMode: JavascriptMode.unrestricted,
              onProgress: (int progress) async {
                javascriptChannels:
                <JavascriptChannel>{_javascriptChannel()};
                print('WebView is loading (progress : $progress%)');
              },
              onWebViewCreated: (controller) {
                print('---onWebViewCreated----${controller.currentUrl()}');
              },
              navigationDelegate: (NavigationRequest request) {
                print('----navigation delegate---${request.url}');

                if (request.url.startsWith('https://xyz.zyz')) {
                  print('APIU CALL FIRST');

                  getSessionID(loginId!);

                  return NavigationDecision.prevent;
                } else if (request.url.startsWith(
                    '${APIMode.SERVICE_BASE_URL}/?csc-tierId=619b7f6cfbacc96bd8fb232a')) {
                  Navigator.pop(context);
                }

                print('allowing navigation to $request');
                return NavigationDecision.navigate;
              },
              onPageStarted: (String url) {
                print('Page started loading: $url');
              },
              onPageFinished: (String url) {
                print('Page finished loading: $url');
              },
              javascriptChannels: <JavascriptChannel>{_javascriptChannel()},
            )
          : Center(child: CircularProgressIndicator()),
    );
  }
}

==> flutter_conscent_plugin-0.3.4.tar.gz: lib/webview.dart <==
import 'package:flutter/material.dart';
import 'package:http/http.dart' as http;
import 'package:shared_preferences/shared_preferences.dart';
import 'package:webview_flutter/webview_flutter.dart';
import 'dart:io' show Platform;
import 'conscent_initializer.dart';
import 'conscent_methods.dart';
import 'Model/api_mode.dart';
import 'Model/login_challengeget.dart';
import 'constants.dart';

void main() {
  runApp(
    const MaterialApp(
      home: WebViewApp(),
    ),
  );
}

class WebViewApp extends StatefulWidget {
  const WebViewApp({super.key});

  @override
  State<WebViewApp> createState() => _WebViewAppState();
}

class _WebViewAppState extends State<WebViewApp> {
  String? loginId;
  // String? sessionId;

  bool showContent = false;
  bool isLoaded = false;
  final clientId = TextEditingController();
  final clientContentId = TextEditingController();
  // final sessionId = TextEditingController();

  @override
  void initState() {
    if (mounted) {
      getLoginChallengeId();
    }
    super.initState();
  }

  getLoginChallengeId() async {
    final prefs = await SharedPreferences.getInstance();
    loginId = prefs.getString('loginID');
    print(loginId.toString());
    getSessionID(loginId.toString());
    setState(() {});
  }

  Future<String> getSessionID(String loginId) async {
    print('getSessionId------');
    var uri = Uri.parse('${APIMode.BASE_URL}api/v1/login-challenge/$loginId');
    print(uri);
    var response = await http.get(uri);
    if (response.statusCode == 200) {
      LoginChallengeget loginChallengeget =
          loginChallengegetFromJson(response.body);
      final prefs = await SharedPreferences.getInstance();
      print('WebViewApp sessionId ${prefs.getString('sessionId')}');
      String sessionId = loginChallengeget.toString();
      prefs.setString('sessionId', sessionId);
      print(loginChallengeget.toJson());
      CircularProgressIndicator();
      return sessionId;
    } else {
      ConscentMethods().onPluginError(response.body);
    }
    return '';
  }

  Future<void> submitDatas(
      String clientId, String clientContentId, String sessionId) async {
    print('sessionId xyz= $sessionId');
    var response = await http
        .post(Uri.parse('${APIMode.BASE_URL}api/v1/content/access'), body: {
      "clientId": '${ConscentInitializer.mClientId}',
      "clientContentId": '${ConscentInitializer.mContentId}',
      "sessionId": sessionId,
    });
    print('-------------------------------------------------------');
    print('${response.body}---- status---${response.statusCode}');

    if (response.statusCode == 201) {
      var responseString = response.body;

      Navigator.pop(context, {"response": responseString});
    } else {
      ConscentMethods().onPluginError(response.body);
    }
  }

  JavascriptChannel _javascriptChannel() {
    print('javascript');
    return JavascriptChannel(
        name: 'LOGINCHALLENGE',
        onMessageReceived: (JavascriptMessage message) async {
          print(message.message);
          if (message.message == 'loginSuccess') {
            CircularProgressIndicator();
            print('javascript----------');
            String sessionId = await getSessionID(loginId!);
            submitDatas('${ConscentInitializer.mClientId}',
                '${ConscentInitializer.mContentId}', sessionId);
          }
        });
  }

  // Home

  Widget homeBody() {
    return !isLoaded
        ? const CircularProgressIndicator()
        : Padding(
            padding: const EdgeInsets.all(8.0),
          );
  }

  //home

  // ... to here.

  @override
  Widget build(BuildContext context) {
    javascriptChannels:
    <JavascriptChannel>{_javascriptChannel()};

    String? userAgent = Constants.userAgent;

    return Scaffold(
      appBar: AppBar(
        title: const Text('Conscent'),
      ),
      body: loginId != null
          ? WebView(
              initialUrl:
                  '${APIMode.SERVICE_BASE_URL}/overlay?clientId=${ConscentInitializer.mClientId}&clientContentId=${ConscentInitializer.mContentId}&loginChallenge=$loginId',
              javascriptMode: JavascriptMode.unrestricted,
            userAgent: Platform.isIOS
            ? '${userAgent!} Safari/605.1'
            : userAgent?.replaceAll("; wv", ""),
              onProgress: (int progress) async {
                javascriptChannels:
                <JavascriptChannel>{_javascriptChannel()};
                print('WebView is loading (progress : $progress%)');
              },
              onWebViewCreated: (controller) {
                print('---onWebViewCreated----${controller.currentUrl()}');
              },
              navigationDelegate: (NavigationRequest request) {
                print('----navigation delegate---${request.url}');

                if (request.url.startsWith('https://xyz.zyz')) {
                  print('APIU CALL FIRST');

                  getSessionID(loginId!);

                  return NavigationDecision.prevent;
                } else if (request.url.startsWith(
                    '${APIMode.SERVICE_BASE_URL}/?csc-tierId=619b7f6cfbacc96bd8fb232a')) {
                  Navigator.pop(context);
                }

                print('allowing navigation to $request');
                return NavigationDecision.navigate;
              },
              onPageStarted: (String url) {
                print('Page started loading: $url');
              },
              onPageFinished: (String url) {
                print('Page finished loading: $url');
              },
              javascriptChannels: <JavascriptChannel>{_javascriptChannel()},
            )
          : Center(child: CircularProgressIndicator()),
    );
  }
}
